@@ -3,11 +3,15 @@ import json
 import kubernetes
 
 from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
-from ocp_resources.resource import NamespacedResource, kube_v1_api
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutWatch
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class ExecOnPodError(Exception):
     def __init__(self, command, rc, out, err):
         self.cmd = command
@@ -85,9 +89,10 @@ class Pod(NamespacedResource):
         """
         error_channel = {}
         stream_closed_error = "stream resp is closed"
-        self.logger.info(f"Execute {command} on {self.name} ({self.node.name})")
+        LOGGER.info(f"Execute {command} on {self.name} ({self.node.name})")
+        kube_v1_api = kubernetes.client.CoreV1Api(api_client=self.client.client)
         resp = kubernetes.stream.stream(
-            api_method=self._kube_v1_api.connect_get_namespaced_pod_exec,
+            api_method=kube_v1_api.connect_get_namespaced_pod_exec,
             name=self.name,
             namespace=self.namespace,
             command=command,
@@ -127,9 +132,6 @@ class Pod(NamespacedResource):
         if rcstring == "Success" or ignore_rc:
             return stdout
 
-        if rcstring == "Failure":
-            raise ExecOnPodError(command=command, rc=-1, out="", err=error_channel)
-
         returncode = [
             int(cause["message"])
             for cause in error_channel["details"]["causes"]
@@ -145,7 +147,7 @@ class Pod(NamespacedResource):
         Returns:
             str: Pod logs.
         """
-        return self._kube_v1_api.read_namespaced_pod_log(
+        return self._kube_api.read_namespaced_pod_log(
             name=self.name, namespace=self.namespace, **kwargs
         )
 
@@ -165,7 +167,3 @@ class Pod(NamespacedResource):
     @property
     def ip(self):
         return self.instance.status.podIP
-
-    @property
-    def _kube_v1_api(self):
-        return kube_v1_api(api_client=self.client.client)
